#include <iostream>
#include <iomanip>
#include <cmath>
#include <algorithm>
#include <string>
#include <vector>
#include <map>
#include <set>

using namespace std;

typedef long long ll;
typedef pair<ll, ll> pll;
#define all(x) (x).begin(), (x).end()

const int inf = 1e9;

struct node {
	int l, r, val;
	node() :l(-1), r(-1), val(inf) {}
	node(int l, int r, int val) :l(l), r(r), val(val) {}
	node operator+(const node& s)const {
		return node(l, s.r, min(val, s.val));
	}
};

int LG = 0;

struct segment_tree {
	int N;
	vector<node> tree;
	segment_tree(int n, const vector<int>& a) :N(1 << LG) {
		tree.resize(2 * N);
		build(1, 0, n - 1, a);
	}
	void build(int v, int l, int r, const vector<int>& a) {
		if (l == r) {
			tree[v] = node(l, l, a[l]);
			return;
		}

		int m = (l + r) / 2;
		build(2 * v, l, m, a);
		build(2 * v + 1, m + 1, r,a);
		tree[v] = tree[v * 2] + tree[v * 2 + 1];
	}

	node get(int v, int l, int r) {
		if (tree[v].r < l || tree[v].l > r)
			return node();

		if (l <= tree[v].l && tree[v].r <= r) {
			return tree[v];
		}

		return get(v * 2, l, r) + get(2 * v + 1, l, r);
	}
};

int main() {
	ios_base::sync_with_stdio(false), cin.tie(NULL); cout.tie(NULL);

	int n, m; cin >> n >> m;
	while ((1 << LG) < 2 * n) {
		LG++;
	}

	int C = n - 1;

	vector<pair<int, int>> a(m);
	for (auto& c : a) {
		cin >> c.first >> c.second;
		c.first--;
		c.second--;
	}
	
	vector<int> dp(2 * n, inf);
	int l = a[0].first, r = a[0].second;
	for (int cur_x = -l; cur_x <= n - 1 - r; cur_x++) {
		dp[cur_x + C] = abs(cur_x);
	}
	segment_tree st(2 * n, dp);

	for (int j = 1; j < m; j++) {
		l = a[j].first, r = a[j].second;
		vector<int> cur_dp(2 * n, inf);
		for (int cur_x = -l; cur_x <= n - 1 - r; cur_x++) {
			int pred_l = max(-n + 1, l + cur_x - a[j - 1].second), pred_r = min(n - 1, r + cur_x - a[j - 1].first);
			cur_dp[cur_x + C] = st.get(1, pred_l + C, pred_r + C).val + abs(cur_x);
		}

		dp = cur_dp;
		st = segment_tree(2 * n, dp);
	}

	int ans = inf;
	for (auto c : dp) {
		ans = min(ans, c);
	}
	cout << ans;

	return 0;
}