#include <iostream>
#include <cmath>
#include <algorithm>
#include <vector>
#include <string>
#include <iomanip>
#include <ext/pb_ds/assoc_container.hpp>
#include <ext/pb_ds/tree_policy.hpp>
#include <set>
#include <map>
#include <queue>
#include <unordered_map>
#include <unordered_set>
#include <stack>
#include <cassert>
#include <cstring>
#include <random>
#include <chrono>
#include <ext/rope>
#include <bitset>

#define sqr(x) ((x) * (x))
#define fi first
#define se second
#define pb push_back
#define all(x) x.begin(),x.end()
#define sz(x) ((ll)(x).size())

using namespace std;
using namespace __gnu_pbds;
using namespace __gnu_cxx;
using ll = long long;
using ld = long double;

template <class T>
using indexed_set = tree <T, null_type, less <T>, rb_tree_tag, tree_order_statistics_node_update>;
mt19937 rnd(std::chrono::high_resolution_clock::now().time_since_epoch().count());
ld Time() { return ld(clock()) / CLOCKS_PER_SEC; }

class Fenwick {
public:
    vector <ll> t;
    int size;

    Fenwick(int n) {
        size = n + 1;
        t.resize(size);
    }

    void update(int pos, ll x) {
        for (; pos < size; pos += (pos & -pos)) {
            t[pos] += x;
        }
    }

    ll calc(int r) {
        ll ans = 0;
        if (r < 1) {
            return 0;
        }

        for (; r > 0; r -= (r & -r)) {
            ans += t[r];
        }

        return ans;
    }

    ll calc(int l, int r) {
        return calc(r) - calc(l - 1);
    }
};

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr); cout.tie(nullptr);

    int n;
    cin >> n;

    vector <ll> a(n + 1);
    set <pair <int, int>> kek;
    vector <bool> known(n + 1);

    Fenwick F(n);

    for (int i = 1; i <= n; ++i) {
        if (kek.count(make_pair(i, i))) {
            continue;
        }

        cout << "? " << i << ' ' << i << endl;
        known[i] = true;

        ll sum;
        int l, r;
        cin >> sum >> l >> r;

        F.update(i, sum);

        a[i] = sum;
        kek.insert(make_pair(l, r));
    }

    for (int i = 1; i <= n; ++i) {
        if (known[i]) {
            continue;
        }

        for (int j = 1; i > j; ++j) {
            if (!known[i - j]) {
                break;
            }

            if (kek.count(make_pair(i - j, i))) {
                continue;
            }

            ll have = F.calc(i - j, i - 1);
            cout << "? " << i - j << ' ' << i << endl;

            ll sum;
            int l, r;
            cin >> sum >> l >> r;

            kek.insert(make_pair(l, r));
            a[i] = sum - have;

            known[i] = true;
            break;
        }

        if (!known[i]) {
            for (int j = 1; i + j <= n; ++j) {
                if (!known[i + j]) {
                    break;
                }

                if (kek.count(make_pair(i, i + j))) {
                    continue;
                }

                ll have = F.calc(i + 1, i + j);
                cout << "? " << i << ' ' << i + j << endl;

                ll sum;
                int l, r;
                cin >> sum >> l >> r;

                kek.insert(make_pair(l, r));
                a[i] = sum - have;

                known[i] = true;
                break;
            }
        }
    }

    for (int i = n; i >= 1; --i) {
        if (known[i]) {
            continue;
        }

        for (int j = 1; j < i; ++j) {
            if (!known[i - j]) {
                break;
            }

            if (kek.count(make_pair(i - j, i))) {
                continue;
            }

            ll have = F.calc(i - j, i - 1);
            cout << "? " << i - j << ' ' << i << endl;

            ll sum;
            int l, r;
            cin >> sum >> l >> r;

            kek.insert(make_pair(l, r));
            a[i] = sum - have;

            known[i] = true;
            break;
        }

        if (!known[i]) {
            for (int j = 1; i + j <= n; ++j) {
                if (!known[i + j]) {
                    break;
                }

                if (kek.count(make_pair(i, i + j))) {
                    continue;
                }

                ll have = F.calc(i + 1, i + j);
                cout << "? " << i << ' ' << i + j << endl;

                ll sum;
                int l, r;
                cin >> sum >> l >> r;

                kek.insert(make_pair(l, r));
                a[i] = sum - have;

                known[i] = true;
                break;
            }
        }
    }

    cout << "!" << endl;
    for (int i = 1; i <= n; ++i) {
        cout << a[i] << ' ';
    }
    cout << endl;

    return 0;
}