#include <iostream>
#include <vector>
#include <map>
#include <math.h>
using namespace std;

vector<int> start;
vector<int> vel;

int gcd(int n, int m)
{
    if(n == 0) return m;
    if(m == 0) return n;
    if(n < m) return gcd(n, m%n);
    else return gcd(n%m, m);
}

struct ratio
{
    int n;
    int m;
    ratio(int x = 0, int y = 1)
    {
        n = x;
        m = y;
        this->simplify();
    }

    void simplify()
    {
        int d = gcd(abs(n),abs(m));
        n = n/d;
        m = m/d;
        if(m < 0) 
        {
            m = -m;
            n = -n;
        }
    }
};

ratio operator+ (const ratio& r1, const ratio& r2)
{
    ratio r(r1.n*r2.m + r1.m*r2.n, r1.m*r2.m);
    r.simplify();
    return r;
}

ratio operator- (const ratio& r1, const ratio& r2)
{
    ratio r(r1.n*r2.m - r1.m*r2.n, r1.m*r2.m);
    r.simplify();
    return r;
}

bool operator< (const ratio& r1, const ratio& r2)
{
    if(r1.n == r2.n)
    {
        return r1.m < r2.m;
    }
    else return r1.n < r2.n;
}

struct ans
{
    int num; //-1 - inf, 0 - zero solutions, 1 - one solution
    ratio r;

    ans(int n = 0, ratio q = ratio())
    {
        num = n;
        r = q;
    }
};

bool operator< (const ans& a1, const ans& a2)
{
    if(a1.num == a2.num)
    {
        return a1.r < a2.r;
    }
    else return a1.num < a2.num;
}

ans solve(int a, int b)
{
    if(a == 0)
    {
        if(b == 0) return ans(-1);
        else return ans(0);
    }
    else return ans(1, ratio(-b, a));
}

int main()
{
#if 1
    int n;
    cin >> n;

    for(int i = 0; i < n; i++)
    {
        int x,v;
        cin >> x >> v;
        start.push_back(x);
        vel.push_back(v);
    }
#endif
#if 0
    ratio r1(14,5);
    ratio r2(14,3);

    ratio r3 = r1-r2;
    cout << r3.n << " " << r3.m; 
#endif

    vector<vector<map<ans,int>>> sol(n, vector<map<ans,int>>(n));
    for(int i = 0; i < n; i++)
    {
        for(int j = i+1; j < n; j++)
        {
            for(int k = 0; k < n; k++)
            {
                if (k == i || k == j) sol[i][j][ans(-1)]++;
                else
                {
                    int y1 = j-i;
                    int y2 = k-j;
                    int v2 = vel[k];
                    int v1 = vel[j];
                    int v0 = vel[i];
                    int x2 = start[k];
                    int x1 = start[j];
                    int x0 = start[i];
                    int a = y1*(v2-v1) - y2*(v1-v0);
                    int b = y1*(x2-x1) - y2*(x1-x0);
                    ans an = solve(a,b);
                    if(an.num == 1 && an.r.n < 0) continue;
                    sol[i][j][an]++;
                }
            }
        }
    }

    int maxans = 0;
    for(int i = 0; i < n; i++)
    {
        for(int j = i+1; j < n; j++)
        {
            int cur = sol[i][j][ans(-1)];
            
            //cout << i << j << " : " << cur << '\n';
            int maxq = 0;
            for(auto x: sol[i][j])
            {
                //cout << i << " " << j << ": " <<  x.first.num << " " << x.first.r.n << " " << x.first.r.m << " - " << x.second << "\n";
                if(x.first.num == 1)
                {
                    maxq = max(maxq, x.second);
                }
            }
            cur += maxq;

            maxans = max(cur, maxans);
        }
    }
    cout << maxans;
}